from dataclasses import dataclass


@dataclass
class SubtitleLine:
    """
    Class to represent a line of a subtitles file.
    """
    
    @property
    def end_time(self) -> int:
        """
        The time moment (in ms) in which the subtitle
        line ends being displayed.
        """
        return self.start_time + self.duration

    def __init__(
        self,
        text: str,
        start_time: int,
        duration: int
    ):
        self.text: str = text
        """
        The text that is displayed in the subtitle line.
        """
        self.start_time: int = start_time
        """
        The time moment (in ms) in which the subtitle 
        line starts being displayed.
        """
        self.duration: int = duration
        """
        The time (in ms) that the subtitle line last
        being displayed.
        """

@dataclass
class Subtitles:
    """
    Class to represent the subtitles of a file.
    """

    @property
    def text(
        self
    ) -> str:
        """
        Get the whole subtitles text by concatenating
        all the subtitle lines.
        """
        return '\n'.join([
            subtitle.text.strip()
            for subtitle in self.subtitles
        ])

    def __init__(
        self,
        subtitles: list[SubtitleLine] = []
    ):
        self.subtitles: list[SubtitleLine] = subtitles
        """
        The list of subtitles line.
        """

    def add_subtitle(
        self,
        subtitle: SubtitleLine
    ):
        self.subtitles.append(subtitle)